@@ -1,10 +1,12 @@
+import typing
 import asyncio
 import logging
-import typing
+import warnings
 
 import serial
 import serial.tools
-import serial_asyncio
+
+from collections import defaultdict
 
 from serial.tools.list_ports import comports as list_com_ports
 
@@ -12,8 +14,18 @@ import zigpy_znp.config as conf
 import zigpy_znp.frames as frames
 
 from zigpy_znp.types import Bytes
+from zigpy_znp.logger import TRACE
 from zigpy_znp.exceptions import InvalidFrame
 
+with warnings.catch_warnings():
+    warnings.filterwarnings(
+        action="ignore",
+        module="serial_asyncio",
+        message='"@coroutine" decorator is deprecated',
+        category=DeprecationWarning,
+    )
+    import serial_asyncio  # noqa: E402
+
 LOGGER = logging.getLogger(__name__)
 
 
@@ -63,10 +75,10 @@ class ZnpMtProtocol(asyncio.Protocol):
         """Callback when data is received."""
         self._buffer += data
 
-        LOGGER.trace("Received data: %s", Bytes.__repr__(data))
+        LOGGER.log(TRACE, "Received data: %s", Bytes.__repr__(data))
 
         for frame in self._extract_frames():
-            LOGGER.trace("Parsed frame: %s", frame)
+            LOGGER.log(TRACE, "Parsed frame: %s", frame)
 
             try:
                 self._api.frame_received(frame.payload)
@@ -77,8 +89,10 @@ class ZnpMtProtocol(asyncio.Protocol):
 
     def send(self, payload: frames.GeneralFrame) -> None:
         """Sends data taking care of framing."""
-        data = frames.TransportFrame(payload).serialize()
-        LOGGER.trace("Sending data: %s", Bytes.__repr__(data))
+        self._transport_write(frames.TransportFrame(payload).serialize())
+
+    def _transport_write(self, data: bytes) -> None:
+        LOGGER.log(TRACE, "Sending data: %s", Bytes.__repr__(data))
         self.transport.write(data)
 
     def _extract_frames(self) -> typing.Iterator[frames.TransportFrame]:
@@ -134,30 +148,67 @@ class ZnpMtProtocol(asyncio.Protocol):
         return f"<{type(self).__name__} for {self._api}>"
 
 
-def guess_port() -> str:
-    """Picks the first USB port with a Texas Instruments vendor ID."""
-    candidates = []
+def find_ti_ports() -> typing.Iterable[
+    typing.Tuple[str, serial.tools.list_ports_common.ListPortInfo]
+]:
+    """
+    Finds all TI serial ports and yields an iterable of tuples, where the first element
+    is the serial number of the device.
+    """
 
-    for port in list_com_ports(include_links=True):
-        # Add only TI devices
-        if port.vid == 0x0451:
-            candidates.append(port)
+    # Each dev kit has two serial ports, one of which is a debugger
+    found_ports = defaultdict(list)
+
+    for port in list_com_ports():
+        if (port.vid, port.pid) == (0x0451, 0x16A8):
+            # CC2531
+            found_ports[port.serial_number].append(port)
+        elif (port.vid, port.pid) == (0x0451, 0xBEF3):
+            # LAUNCHXL-CC26X2R1
+            found_ports[port.serial_number].append(port)
+        elif (port.vid, port.pid) == (0x10C4, 0xEA60):
+            # slae.sh CC2652RB stick
+            if "slae.sh cc2652rb stick" in (port.product or ""):
+                found_ports[port.serial_number].append(port)
+            else:
+                found_ports["CP210x"].append(port)
+        elif (port.vid, port.pid) == (0x1A86, 0x7523):
+            # ZZH (CH340, no way to distinguish it from any other CH340 device)
+            found_ports["CH340"].append(port)
+
+    # Python guarantees insertion order for dictionaries
+    for serial_number, ports in found_ports.items():
+        first_port = sorted(ports, key=lambda p: p.device)[0]
+
+        yield serial_number, first_port
+
+
+def guess_port() -> str:
+    """
+    Autodetects the best TI radio.
+
+    The CH340 used by the ZZH adapter has no distinguishing information so it is not
+    possible to tell whether or not a port belongs to a cheap Arduino clone or the ZZH.
+    Known TI serial ports are picked over the CH340, which may belong to a cheap Arduino
+    clone instead of the ZZH.
+    """
+
+    # Move generic serial adapters to the bottom of the list but keep the order of the
+    # rest because Python's sort is stable.
+    candidates = sorted(find_ti_ports(), key=lambda p: p[0] in ("CH340", "CP210x"))
 
     if not candidates:
-        raise RuntimeError("Could not auto detect any TI ports")
+        raise RuntimeError("Failed to detect any TI ports")
 
-    # Is there no better heuristic than picking the first TI device?
-    candidates.sort(key=lambda p: p.location)
-    device = candidates[0].device
+    _, port = candidates[0]
 
     if len(candidates) > 1:
         LOGGER.warning(
-            "Found multiple Texas Instruments devices: %s",
-            [c.__dict__ for c in candidates],
+            "Found multiple possible Texas Instruments devices: %s", candidates,
         )
-        LOGGER.warning("Picking the first one: %s", device)
+        LOGGER.warning("Picking the first one: %s", port)
 
-    return device
+    return port.device
 
 
 async def connect(config: conf.ConfigType, api) -> ZnpMtProtocol:
